@@ -1,5 +1,5 @@
 require "digest/md5"
-require "hashie/mash"
+require "hashie"
 
 module ChefZero
   module ChefData
@@ -13,7 +13,9 @@ module ChefZero
         end
 
         result = files_from(cookbook)
-        recipe_names = result[:recipes].map do |recipe|
+        recipe_names = result[:all_files].select do |file|
+          file[:name].start_with?("recipes/")
+        end.map do |recipe|
           recipe_name = recipe[:name][0..-2]
           recipe_name == "default" ? name : "#{name}::#{recipe_name}"
         end
@@ -29,18 +31,16 @@ module ChefZero
 
       def self.metadata_from(directory, name, version, recipe_names)
         metadata = PretendCookbookMetadata.new(PretendCookbook.new(name, recipe_names))
-        # If both .rb and .json exist, read .rb
-        # TODO if recipes has 3 recipes in it, and the Ruby/JSON has only one, should
-        # the resulting recipe list have 1, or 3-4 recipes in it?
-        if has_child(directory, "metadata.rb")
+        # If both .rb and .json exist, read .json
+        if has_child(directory, "metadata.json")
+          metadata.from_json(read_file(directory, "metadata.json"))
+        elsif has_child(directory, "metadata.rb")
           begin
             file = filename(directory, "metadata.rb") || "(#{name}/metadata.rb)"
             metadata.instance_eval(read_file(directory, "metadata.rb"), file)
           rescue
             ChefZero::Log.error("Error loading cookbook #{name}: #{$!}\n  #{$!.backtrace.join("\n  ")}")
           end
-        elsif has_child(directory, "metadata.json")
-          metadata.from_json(read_file(directory, "metadata.json"))
         end
         result = {}
         metadata.to_hash.each_pair do |key, value|
@@ -88,26 +88,10 @@ module ChefZero
           cookbook_arg(:supports, cookbook, version_constraints)
         end
 
-        def recommends(cookbook, *version_constraints)
-          cookbook_arg(:recommendations, cookbook, version_constraints)
-        end
-
-        def suggests(cookbook, *version_constraints)
-          cookbook_arg(:suggestions, cookbook, version_constraints)
-        end
-
-        def conflicts(cookbook, *version_constraints)
-          cookbook_arg(:conflicting, cookbook, version_constraints)
-        end
-
         def provides(cookbook, *version_constraints)
           cookbook_arg(:providing, cookbook, version_constraints)
         end
 
-        def replaces(cookbook, *version_constraints)
-          cookbook_arg(:replacing, cookbook, version_constraints)
-        end
-
         def gem(*opts)
           self[:gems] ||= []
           self[:gems] << opts
@@ -121,10 +105,6 @@ module ChefZero
           self[:attributes][name] = options
         end
 
-        def grouping(name, options)
-          self[:grouping][name] = options
-        end
-
         def cookbook_arg(key, cookbook, version_constraints)
           self[key][cookbook] = version_constraints.first || ">= 0.0.0"
         end
@@ -144,19 +124,14 @@ module ChefZero
 
       def self.files_from(directory)
         # TODO some support .rb only
+        result = load_files(directory)
+
+        set_specificity(result, :templates)
+        set_specificity(result, :files)
+
         result = {
-          :attributes => load_child_files(directory, "attributes", false),
-          :definitions => load_child_files(directory, "definitions", false),
-          :recipes => load_child_files(directory, "recipes", false),
-          :libraries => load_child_files(directory, "libraries", true),
-          :templates => load_child_files(directory, "templates", true),
-          :files => load_child_files(directory, "files", true),
-          :resources => load_child_files(directory, "resources", true),
-          :providers => load_child_files(directory, "providers", true),
-          :root_files => load_files(directory, false),
+          all_files: result,
         }
-        set_specificity(result[:templates])
-        set_specificity(result[:files])
         result
       end
 
@@ -201,45 +176,52 @@ module ChefZero
         end
       end
 
-      def self.load_child_files(parent, key, recursive)
-        result = load_files(get_directory(parent, key), recursive)
+      def self.load_child_files(parent, key, recursive, part)
+        result = load_files(get_directory(parent, key), recursive, part)
         result.each do |file|
           file[:path] = "#{key}/#{file[:path]}"
         end
         result
       end
 
-      def self.load_files(directory, recursive)
+      def self.load_files(directory, recursive = true, part = nil)
         result = []
         if directory
           list(directory).each do |child_name|
             dir = get_directory(directory, child_name)
             if dir
+              child_part = child_name if part.nil?
               if recursive
-                result += load_child_files(directory, child_name, recursive)
+                result += load_child_files(directory, child_name, recursive, child_part)
               end
             else
-              result += load_file(read_file(directory, child_name), child_name)
+              result += load_file(read_file(directory, child_name), child_name, part)
             end
           end
         end
         result
       end
 
-      def self.load_file(value, name)
+      def self.load_file(value, name, part = nil)
+        specific_name = part ? "#{part}/#{name}" : name
         [{
-          :name => name,
+          :name => specific_name,
           :path => name,
           :checksum => Digest::MD5.hexdigest(value),
           :specificity => "default",
         }]
       end
 
-      def self.set_specificity(files)
+      def self.set_specificity(files, type)
         files.each do |file|
+          next unless file[:name].split("/")[0] == type.to_s
+
           parts = file[:path].split("/")
-          raise "Only directories are allowed directly under templates or files: #{file[:path]}" if parts.size == 2
-          file[:specificity] = parts[1]
+          file[:specificity] = if parts.size == 2
+                                 "default"
+                               else
+                                 parts[1]
+                               end
         end
       end
     end
