@@ -16,7 +16,7 @@
 # limitations under the License.
 #
 
-require 'chef_zero/data_store/data_error'
+require "chef_zero/data_store/data_error"
 
 module ChefZero
   module DataStore
@@ -26,4 +26,4 @@ module ChefZero
       end
     end
   end
-end
\ No newline at end of file
+end
