@@ -9,7 +9,7 @@ module ChefZero
 
       # GET /organizations/ORG/cookbook_artifacts/NAME/IDENTIFIER
       def get(request)
-        cookbook_data = normalize(request, parse_json(get_data(request)))
+        cookbook_data = normalize(request, get_data(request))
         return json_response(200, cookbook_data)
       end
 
@@ -19,7 +19,8 @@ module ChefZero
           return error(409, "Cookbooks cannot be modified, and a cookbook with this identifier already exists.")
         end
 
-        set_data(request, nil, request.body, :create_dir)
+        cb_data = normalize(request, request.body)
+        set_data(request, nil, to_json(cb_data), :create_dir)
 
         return already_json_response(201, request.body)
       end
@@ -28,7 +29,7 @@ module ChefZero
       def delete(request)
         begin
           doomed_cookbook_json = get_data(request)
-          identified_cookbook_data = normalize(request, parse_json(doomed_cookbook_json))
+          identified_cookbook_data = normalize(request, doomed_cookbook_json)
           delete_data(request)
 
           # go through the recipes and delete stuff in the file store.
@@ -59,9 +60,10 @@ module ChefZero
       end
 
       def normalize(request, cookbook_artifact_data)
+        cookbook = parse_json(cookbook_artifact_data)
         ChefData::DataNormalizer.normalize_cookbook(self, request.rest_path[0..1],
-                                                    cookbook_artifact_data, request.rest_path[3], request.rest_path[4],
-                                                    request.base_uri, request.method, true)
+                                                    cookbook, request.rest_path[3], request.rest_path[4],
+                                                    request.base_uri, request.method, true, api_version: request.api_version)
       end
     end
   end
