@@ -23,6 +23,22 @@ module ChefZero
         results
       end
 
+      def format_universe_list(request, cookbooks_list)
+        results = {}
+        cookbooks_list.each do |name, versions|
+          results[name] ||= {}
+          versions.each do |version|
+            cookbook_data = FFI_Yajl::Parser.parse(get_data(request, request.rest_path[0..1] + [ "cookbooks", name, version ], :nil))
+            results[name][version] ||= {
+              "dependencies" => cookbook_data["metadata"]["dependencies"],
+              "location_path" => build_uri(request.base_uri, request.rest_path[0..1] + ["cookbooks", name, version]),
+              "location_type" => "chef_server",
+            }
+          end
+        end
+        results
+      end
+
       def all_cookbooks_list(request)
         result = {}
         # Race conditions exist here (if someone deletes while listing).  I don't care.
@@ -47,18 +63,15 @@ module ChefZero
       end
 
       def recipe_names(cookbook_name, cookbook)
-        result = []
-        if cookbook["recipes"]
-          cookbook["recipes"].each do |recipe|
-            if recipe["path"] == "recipes/#{recipe['name']}" && recipe["name"][-3..-1] == ".rb"
-              if recipe["name"] == "default.rb"
-                result << cookbook_name
-              end
-              result << "#{cookbook_name}::#{recipe['name'][0..-4]}"
-            end
+        cookbook["all_files"].inject([]) do |acc, file|
+          part, name = file["name"].split("/")
+          next unless part == "recipes" || File.extname(name) != ".rb"
+          if name == "default.rb"
+            acc << cookbook_name
+          else
+            acc << "#{cookbook_name}::#{File.basename(name, ".rb")}"
           end
         end
-        result
       end
     end
   end
