@@ -19,15 +19,7 @@ module ChefZero
     end
 
     def check_api_version(request)
-      return if request.api_version.nil? # Not present in headers
-      version = request.api_version.to_i
-
-      unless version.to_s == request.api_version.to_s # Version is not an Integer
-        return json_response(406,
-          { "username" => request.requestor },
-          request_version: -1, response_version: -1
-        )
-      end
+      version = request.api_version
 
       if version > MAX_API_VERSION || version < MIN_API_VERSION
         response = {
@@ -38,10 +30,15 @@ module ChefZero
         }
 
         return json_response(406,
-          response,
-          request_version: version, response_version: -1
-        )
+                             response,
+                             request_version: version, response_version: -1
+                            )
       end
+    rescue ArgumentError
+      return json_response(406,
+                           { "username" => request.requestor },
+                           request_version: -1, response_version: -1
+                          )
     end
 
     def call(request)
@@ -234,6 +231,16 @@ module ChefZero
       [response_code, { "Content-Type" => "text/plain" }, text]
     end
 
+    # rfc090 returns 404 error or 200 with an emtpy body
+    # @param [ChefZero::RestRequest] request The HTTP request object
+    #
+    # @return (see #json_response)
+    #
+    def head_request(request)
+      get_data(request) # will raise 404 if non-existant
+      json_response(200, nil)
+    end
+
     # Returns an Array with the response code, HTTP headers, and JSON body.
     #
     # @param [Fixnum] response_code The HTTP response code
