@@ -16,13 +16,14 @@ module ChefZero
         def matches_doc?(doc)
           matches_values?(doc[DEFAULT_FIELD])
         end
+
         def matches_values?(values)
           values.any? { |value| !@regexp.match(value).nil? }
         end
 
         DEFAULT_FIELD = "text"
-        WORD_CHARACTER = "[A-Za-z0-9@._':]"
-        NON_WORD_CHARACTER = "[^A-Za-z0-9@._':]"
+        WORD_CHARACTER = "[A-Za-z0-9@._':\-]"
+        NON_WORD_CHARACTER = "[^A-Za-z0-9@._':\-]"
       end
     end
   end
