@@ -1,4 +1,5 @@
 #!/usr/bin/env ruby
+require "json"
 require "bundler"
 require "bundler/setup"
 
@@ -107,6 +108,10 @@ begin
       start_chef_server
     end
 
+  test_secrets = JSON.parse(File.read("spec/support/secrets.json"))
+  ENV["SUPERUSER_KEY"] = test_secrets["chef-server"]["superuser_key"]
+  ENV["WEBUI_KEY"] = test_secrets["chef-server"]["webui_key"]
+
   require "rspec/core"
   require "pedant"
   require "pedant/organization"
@@ -125,12 +130,6 @@ begin
                       "--skip-organizations",
                       "--skip-multiuser",
                       "--skip-user-keys",
-
-                      # chef-zero has some non-removable quirks, such as the fact that files
-                      # with 255-character names cannot be stored in local mode. This is
-                      # reserved only for quirks that are *irrevocable* and by design; and
-                      # should barely be used at all.
-                      "--skip-chef-zero-quirks",
                     ]
                   else
                     []
@@ -162,6 +161,10 @@ begin
     # Chef Zero does not intend to support authorization the way erchef does.
     "--skip-authorization",
 
+    # Chef Zero does not intend to support oc_id authentication/authorization
+    # the way erchef does.
+    "--skip-oc_id",
+
     # Omnibus tests depend on erchef features that are specific to erchef and
     # bundled in the omnibus package. Currently the only test in this category
     # is for the search reindexing script.
@@ -176,8 +179,13 @@ begin
 
     # Chef 12 features not yet 100% supported by Chef Zero
 
-    # The universe endpoint is unlikely to ever make sense for Chef Zero
-    "--skip-universe",
+    # chef-zero has some non-removable quirks, such as the fact that files
+    # with 255-character names cannot be stored in local mode. This is
+    # reserved only for quirks that are *irrevocable* and by design; and
+    # should barely be used at all. This is also used to skip the user acl
+    # tests from chef-server as the user acls are not supported in chef-zero
+    # at this time.
+    "--skip-chef-zero-quirks",
   ]
 
   # The knife tests are very slow and don't give us a lot of extra coverage,
